==> amity-sdk-7.3.1-alpha01-sources.jar: main/com/amity/socialcloud/sdk/social/domain/post/create/VideoPostCreateUseCase.kt <==
package com.amity.socialcloud.sdk.social.domain.post.create

import com.amity.socialcloud.sdk.model.core.error.AmityError
import com.amity.socialcloud.sdk.model.core.error.AmityException
import com.amity.socialcloud.sdk.model.core.file.AmityVideo
import com.amity.socialcloud.sdk.model.social.post.AmityPost
import com.amity.socialcloud.sdk.social.data.post.PostRepository
import com.amity.socialcloud.sdk.social.domain.post.PostGetUseCase
import com.ekoapp.ekosdk.internal.usecase.post.PostCreateUseCase
import com.google.gson.JsonObject
import io.reactivex.rxjava3.core.Single

internal class VideoPostCreateUseCase : PostCreateUseCase {

    fun execute(
        targetType: String,
        targetId: String,
        videos: List<AmityVideo>,
        text: String,
        metadata: JsonObject?,
        mentionUserIds: List<String>?
    ): Single<AmityPost> {
        return PostRepository().createPostV4(
            targetType = targetType,
            targetId = targetId,
            data = composeData(text),
            dataType = null,
            attachments = mapAttachments(videos, AmityPost.DataType.VIDEO.getApiKey()),
            metadata = metadata,
            mentionees = mapMentionees(mentionUserIds)
        ).flatMap {
            val post = PostGetUseCase().execute(it)
            if (post != null) {
                Single.just(post)
            } else {
                Single.error(
                    AmityException.create(
                        "Post not found",
                        null,
                        AmityError.ITEM_NOT_FOUND
                    )
                )
            }
        }
    }

    private fun composeData(text: String): JsonObject {
        return JsonObject().apply { addProperty("text", text) }
    }

}

==> amity-sdk-7.9.0-alpha01-sources.jar: main/com/amity/socialcloud/sdk/social/domain/post/create/VideoPostCreateUseCase.kt <==
package com.amity.socialcloud.sdk.social.domain.post.create

import com.amity.socialcloud.sdk.model.core.error.AmityError
import com.amity.socialcloud.sdk.model.core.error.AmityException
import com.amity.socialcloud.sdk.model.core.file.AmityVideo
import com.amity.socialcloud.sdk.model.social.post.AmityPost
import com.amity.socialcloud.sdk.social.data.post.PostRepository
import com.amity.socialcloud.sdk.social.domain.post.PostGetUseCase
import com.ekoapp.ekosdk.internal.usecase.post.PostCreateUseCase
import com.google.gson.JsonObject
import io.reactivex.rxjava3.core.Single

internal class VideoPostCreateUseCase : PostCreateUseCase {

    fun execute(
        targetType: String,
        targetId: String,
        videos: List<AmityVideo>,
        text: String,
        title: String?,
        metadata: JsonObject?,
        mentionUserIds: List<String>?
    ): Single<AmityPost> {
        return PostRepository().createPostV4(
            targetType = targetType,
            targetId = targetId,
            data = composeData(text, title),
            dataType = null,
            attachments = mapAttachments(videos, AmityPost.DataType.VIDEO.getApiKey()),
            metadata = metadata,
            mentionees = mapMentionees(mentionUserIds)
        ).flatMap {
            val post = PostGetUseCase().execute(it)
            if (post != null) {
                Single.just(post)
            } else {
                Single.error(
                    AmityException.create(
                        "Post not found",
                        null,
                        AmityError.ITEM_NOT_FOUND
                    )
                )
            }
        }
    }

    private fun composeData(text: String, title: String?): JsonObject {
        return JsonObject().apply {
            addProperty("text", text)
            title?.takeIf { it.isNotBlank() }?.let {
                addProperty("title", it)
            }
        }
    }
}
